@@ -2,8 +2,10 @@ import unittest
 import re
 import os.path
 import tesserocr
+
 try:
     from PIL import Image
+
     pil_installed = True
 except ImportError:
     pil_installed = False
@@ -12,8 +14,8 @@ except ImportError:
 def version_to_int(version):
     subversion = None
     subtrahend = 0
-    # Subtracts a certain amount from the version number to differentiate between
-    # alpha, beta and release versions.
+    # Subtracts a certain amount from the version number to differentiate
+    # between alpha, beta and release versions.
     if "alpha" in version:
         version_split = version.split("alpha")
         subversion = version_split[1]
@@ -22,18 +24,19 @@ def version_to_int(version):
         version_split = version.split("beta")
         subversion = version_split[1]
         subtrahend = 1
-    version = re.search(r'((?:\d+\.)+\d+)', version).group()
-    # Split the groups on ".", take only the first one, and print each group with leading 0 if needed
-    # To be safe, also handle cases where an extra group is added to the version string, or if one or two groups
-    # are dropped.
-    version_groups = (version.split('.') + [0, 0])[:3]
+    version = re.search(r"((?:\d+\.)+\d+)", version).group()
+    # Split the groups on ".", take only the first one, and print each
+    # group with leading 0 if needed. To be safe, also handle cases where
+    # an extra group is added to the version string, or if one or two
+    # groups are dropped.
+    version_groups = (version.split(".") + [0, 0])[:3]
     version_str = "{:02}{:02}{:02}".format(*map(int, version_groups))
     version_str = str((int(version_str, 10) - subtrahend))
     # Adds a 2 digit subversion number for the subversionrelease.
     subversion_str = "00"
-    if subversion is not None and subversion is not "":
-        subversion = re.search(r'(?:\d+)', subversion).group()
-        subversion_groups = (subversion.split('-') + [0, 0])[:1]
+    if subversion is not None and subversion != "":
+        subversion = re.search(r"(?:\d+)", subversion).group()
+        subversion_groups = (subversion.split("-") + [0, 0])[:1]
         subversion_str = "{:02}".format(*map(int, subversion_groups))
     version_str += subversion_str
     return int(version_str, 16)
@@ -45,11 +48,11 @@ _TESSERACT_VERSION = version_to_int(tesserocr.PyTessBaseAPI.Version())
 class TestTessBaseApi(unittest.TestCase):
 
     _test_dir = os.path.abspath(os.path.dirname(__file__))
-    _image_file = os.path.join(_test_dir, 'eurotext.tif')
+    _image_file = os.path.join(_test_dir, "eurotext.png")
 
     def setUp(self):
         if pil_installed:
-            with open(self._image_file, 'rb') as f:
+            with open(self._image_file, "rb") as f:
                 self._image = Image.open(f)
                 self._image.load()
         self._api = tesserocr.PyTessBaseAPI(init=True)
@@ -71,27 +74,27 @@ class TestTessBaseApi(unittest.TestCase):
     def test_init_full(self):
         """Test InitFull."""
         # check default settings
-        self.assertEqual(self._api.GetVariableAsString('file_type'), '.tif')
-        self.assertEqual(self._api.GetVariableAsString('edges_childarea'), '0.5')
+        self.assertEqual(self._api.GetVariableAsString("file_type"), ".tif")
+        self.assertEqual(self._api.GetVariableAsString("edges_childarea"), "0.5")
         # use box.train config variables
-        configs = ['box.train']
+        configs = ["box.train"]
         # change edges_childarea
-        vars_ = {'edges_childarea': '0.7'}
+        vars_ = {"edges_childarea": "0.7"}
         self._api.End()
         self._api.InitFull(configs=configs, variables=vars_)
         # assert file_type from box.train and custom edges_childarea
-        self.assertEqual(self._api.GetVariableAsString('file_type'), '.bl')
-        self.assertEqual(self._api.GetVariableAsString('edges_childarea'), '0.7')
+        self.assertEqual(self._api.GetVariableAsString("file_type"), ".bl")
+        self.assertEqual(self._api.GetVariableAsString("edges_childarea"), "0.7")
         # reset back to default
         self._api.End()
         self._api.Init()
 
     def test_init(self):
         """Test Init calls with different lang and oem."""
-        self._api.Init(lang='eng+osd')
-        self.assertEqual(self._api.GetInitLanguagesAsString(), 'eng+osd')
-        self._api.Init(lang='eng')
-        self.assertEqual(self._api.GetInitLanguagesAsString(), 'eng')
+        self._api.Init(lang="eng+osd")
+        self.assertEqual(self._api.GetInitLanguagesAsString(), "eng+osd")
+        self._api.Init(lang="eng")
+        self.assertEqual(self._api.GetInitLanguagesAsString(), "eng")
         self._api.Init(oem=tesserocr.OEM.TESSERACT_ONLY)
         self.assertEqual(self._api.oem(), tesserocr.OEM.TESSERACT_ONLY)
 
@@ -100,7 +103,7 @@ class TestTessBaseApi(unittest.TestCase):
         """Test SetImage and GetUTF8Text."""
         self._api.SetImage(self._image)
         text = self._api.GetUTF8Text()
-        self.assertIn('quick', text)
+        self.assertIn("quick", text)
         text2 = tesserocr.image_to_text(self._image)
         self.assertEqual(text, text2)
 
@@ -108,7 +111,7 @@ class TestTessBaseApi(unittest.TestCase):
         """Test SetImageFile and GetUTF8Text."""
         self._api.SetImageFile(self._image_file)
         text = self._api.GetUTF8Text()
-        self.assertIn('quick', text)
+        self.assertIn("quick", text)
         text2 = tesserocr.file_to_text(self._image_file)
         self.assertEqual(text, text2)
 
@@ -134,7 +137,9 @@ class TestTessBaseApi(unittest.TestCase):
         """Test GetDatapath and Init with an invalid data path."""
         path = self._api.GetDatapath()
         self._api.End()
-        self.assertRaises(RuntimeError, self._api.Init, path=(self._test_dir + os.path.sep))  # no tessdata
+        self.assertRaises(
+            RuntimeError, self._api.Init, path=(self._test_dir + os.path.sep)
+        )  # no tessdata
         if _TESSERACT_VERSION >= 0x3999800:
             new_path = path
         else:
@@ -145,17 +150,17 @@ class TestTessBaseApi(unittest.TestCase):
 
     def test_langs(self):
         """Test get langs methods."""
-        self._api.Init(lang='eng')
+        self._api.Init(lang="eng")
         lang = self._api.GetInitLanguagesAsString()
-        self.assertEqual(lang, 'eng')
+        self.assertEqual(lang, "eng")
         langs = self._api.GetLoadedLanguages()
-        self.assertEqual(langs, ['eng'])
-        self.assertIn('eng', self._api.GetAvailableLanguages())
+        self.assertEqual(langs, ["eng"])
+        self.assertIn("eng", self._api.GetAvailableLanguages())
 
     def test_variables(self):
         """Test SetVariable and GetVariableAsString."""
-        self._api.SetVariable('debug_file', '/dev/null')
-        self.assertEqual(self._api.GetVariableAsString('debug_file'), '/dev/null')
+        self._api.SetVariable("debug_file", "/dev/null")
+        self.assertEqual(self._api.GetVariableAsString("debug_file"), "/dev/null")
 
     @unittest.skipIf(not pil_installed, "Pillow not installed")
     def test_rectangle(self):
@@ -223,17 +228,25 @@ class TestTessBaseApi(unittest.TestCase):
         self._api.SetPageSegMode(tesserocr.PSM.OSD_ONLY)
         self._api.SetImageFile(self._image_file)
         orientation = self._api.DetectOS()
-        all(self.assertIn(k, orientation) for k in ['sconfidence', 'oconfidence', 'script', 'orientation'])
-        self.assertEqual(orientation['orientation'], 0)
-        languages = tesserocr.get_languages()[1] # this is sorted alphabetically!
-        self.assertLess(orientation['script'], len(languages))
-        script_name = languages[orientation['script']] # therefore does not work
-        #self.assertEqual(script_name, 'Latin') # cannot test: not reliable
+        all(
+            self.assertIn(k, orientation)
+            for k in ["sconfidence", "oconfidence", "script", "orientation"]
+        )
+        self.assertEqual(orientation["orientation"], 0)
+        # this is sorted alphabetically!
+        languages = tesserocr.get_languages()[1]
+        self.assertLess(orientation["script"], len(languages))
+        # therefore does not work
+        # script_name = languages[orientation["script"]]
+        # self.assertEqual(script_name, 'Latin') # cannot test: not reliable
         if _TESSERACT_VERSION >= 0x3999800:
             orientation = self._api.DetectOrientationScript()
-            all(self.assertIn(k, orientation) for k in ['orient_deg', 'orient_conf', 'script_name', 'script_conf'])
-            self.assertEqual(orientation['orient_deg'], 0)
-            self.assertEqual(orientation['script_name'], 'Latin')
+            all(
+                self.assertIn(k, orientation)
+                for k in ["orient_deg", "orient_conf", "script_name", "script_conf"]
+            )
+            self.assertEqual(orientation["orient_deg"], 0)
+            self.assertEqual(orientation["script_name"], "Latin")
 
     def test_clear(self):
         """Test Clear."""
@@ -272,10 +285,10 @@ class TestTessBaseApi(unittest.TestCase):
         result = self._api.GetComponentImages(tesserocr.RIL.BLOCK, True)
         # Test if not empty
         self.assertTrue(result)
-        _, xywh, _, _ = result[0] # bbox of largest
-        self.assertIn('w', xywh)
-        self.assertIn('h', xywh)
-        area = xywh['w'] * xywh['h']
+        _, xywh, _, _ = result[0]  # bbox of largest
+        self.assertIn("w", xywh)
+        self.assertIn("h", xywh)
+        area = xywh["w"] * xywh["h"]
         # Test if the largest block is quite large
         self.assertGreater(area, 400000)
 
@@ -286,7 +299,7 @@ class TestTessBaseApi(unittest.TestCase):
         # Test if not empty
         self.assertTrue(layout)
         self.assertFalse(layout.Empty(tesserocr.RIL.BLOCK))
-        result = layout.BoundingBox(tesserocr.RIL.BLOCK) # bbox of largest
+        result = layout.BoundingBox(tesserocr.RIL.BLOCK)  # bbox of largest
         self.assertIsNot(result, None)
         x0, y0, x1, y1 = result
         area = (x1 - x0) * (y1 - y0)
@@ -300,7 +313,7 @@ class TestTessBaseApi(unittest.TestCase):
         # Test if not empty
         self.assertTrue(layout)
         self.assertFalse(layout.Empty(tesserocr.RIL.BLOCK))
-        result = layout.BlockPolygon() # polygon of largest
+        result = layout.BlockPolygon()  # polygon of largest
         # Test if not empty
         self.assertIsNot(result, None)
         # Test there are at least 4 contour points
@@ -318,7 +331,7 @@ class TestTessBaseApi(unittest.TestCase):
         res = self._api.Recognize(1)
         self.assertFalse(res)
         self._api.SetImageFile(self._image_file)
-        # timeout after 10 seocnds (unlikely)
+        # timeout after 10 seconds (unlikely)
         res = self._api.Recognize(10000)
         self.assertTrue(res)
         self._api.SetImageFile(self._image_file)
@@ -332,10 +345,10 @@ class TestTessBaseApi(unittest.TestCase):
         self._api.Recognize()
         it = self._api.GetIterator()
         attrs = it.RowAttributes()
-        self.assertIsInstance(attrs['row_height'], float)
-        self.assertIsInstance(attrs['ascenders'], float)
-        self.assertIsInstance(attrs['descenders'], float)
+        self.assertIsInstance(attrs["row_height"], float)
+        self.assertIsInstance(attrs["ascenders"], float)
+        self.assertIsInstance(attrs["descenders"], float)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
